@@ -267,7 +267,7 @@ class XGBoostGBTreeClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'd3m-common-primitives',
-                'version': '2022.1.5',
+                'version': '2022.2.17',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.GRADIENT_BOOSTING,
@@ -284,7 +284,7 @@ class XGBoostGBTreeClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs
         }
     )
 
-    _random_state = np.random.RandomState
+    _random_state: np.random.RandomState
     _verbose: int
     _training_inputs: Optional[Inputs]
     _training_outputs: Optional[Outputs]
